afaa5fcf96
1. Changed test macro to emit line numbers 2. Added getcacheconfig api test for nvcc path 3. Fixed hipFuncCache_t data type TODO: With this commit, right now there are 2 func cache datatypes a. hipFuncCache_t for runtime API b. hipFuncCache for driver API Map these to a single data type Change-Id: Ia47c9f5d7c2633638051bf17b1103048a1ede973
40 строки
1.8 KiB
C++
40 строки
1.8 KiB
C++
/*
|
|
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
|
|
Permission is hereby granted, free of charge, to any person obtaining a copy
|
|
of this software and associated documentation files (the "Software"), to deal
|
|
in the Software without restriction, including without limitation the rights
|
|
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
|
copies of the Software, and to permit persons to whom the Software is
|
|
furnished to do so, subject to the following conditions:
|
|
The above copyright notice and this permission notice shall be included in
|
|
all copies or substantial portions of the Software.
|
|
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
|
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
|
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
|
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
|
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
|
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
|
THE SOFTWARE.
|
|
*/
|
|
|
|
#include<hip/hip_runtime_api.h>
|
|
#include"test_common.h"
|
|
|
|
int main()
|
|
{
|
|
int val;
|
|
hipDeviceAttribute_t attr = hipDeviceAttributeMaxThreadsPerBlock; ///< Maximum number of threads per block.
|
|
|
|
HIP_PRINT_STATUS(hipDeviceGetAttribute(NULL, attr, 0));
|
|
HIP_PRINT_STATUS(hipDeviceGetAttribute(&val, attr, 0));
|
|
HIP_PRINT_STATUS(hipDeviceGetAttribute(NULL, attr, -1));
|
|
HIP_PRINT_STATUS(hipDeviceGetAttribute(&val, attr, -1));
|
|
attr = hipDeviceAttribute_t(91);
|
|
|
|
HIP_PRINT_STATUS(hipDeviceGetAttribute(NULL, attr, 0));
|
|
HIP_PRINT_STATUS(hipDeviceGetAttribute(&val, attr, 0));
|
|
HIP_PRINT_STATUS(hipDeviceGetAttribute(NULL, attr, -1));
|
|
HIP_PRINT_STATUS(hipDeviceGetAttribute(&val, attr, -1));
|
|
|
|
}
|